@@ -1,7 +1,7 @@
 # coding: utf-8
 from __future__ import print_function, unicode_literals
 import logging
-import multiprocessing
+import json
 
 from .compat import queue
 from .helpers import DEFAULT_CONTEXT
@@ -9,7 +9,7 @@ from .flusher import FlushWorker
 from .uploader import Uploader
 from .frame import create_frame
 
-DEFAULT_HOST = 'https://in.logtail.com'
+DEFAULT_HOST = 'https://in.logs.betterstack.com'
 DEFAULT_BUFFER_CAPACITY = 1000
 DEFAULT_FLUSH_INTERVAL = 1
 DEFAULT_RAISE_EXCEPTIONS = False
@@ -32,7 +32,7 @@ class LogtailHandler(logging.Handler):
         self.source_token = source_token
         self.host = host
         self.context = context
-        self.pipe = multiprocessing.JoinableQueue(maxsize=buffer_capacity)
+        self.pipe = queue.Queue(maxsize=buffer_capacity)
         self.uploader = Uploader(self.source_token, self.host)
         self.drop_extra_events = drop_extra_events
         self.include_extra_attributes = include_extra_attributes
@@ -40,31 +40,34 @@ class LogtailHandler(logging.Handler):
         self.flush_interval = flush_interval
         self.raise_exceptions = raise_exceptions
         self.dropcount = 0
+        # Do not initialize the flush thread yet because it causes issues on Render.
+        self.flush_thread = None
+
+    def ensure_flush_thread_alive(self):
+        if self.flush_thread and self.flush_thread.is_alive():
+            return
+
         self.flush_thread = FlushWorker(
             self.uploader,
             self.pipe,
             self.buffer_capacity,
             self.flush_interval
         )
-        if self._is_main_process():
-            self.flush_thread.start()
-
-    def _is_main_process(self):
-        return multiprocessing.current_process()._parent_pid == None
+        self.flush_thread.start()
 
     def emit(self, record):
         try:
-            if self._is_main_process() and not self.flush_thread.is_alive():
-                self.flush_thread.start()
+            self.ensure_flush_thread_alive()
+
             message = self.format(record)
             frame = create_frame(record, message, self.context, include_extra_attributes=self.include_extra_attributes)
+            serializable_frame = json.loads(json.dumps(frame, default=str))
             try:
-                self.pipe.put(frame, block=(not self.drop_extra_events))
+                self.pipe.put(serializable_frame, block=(not self.drop_extra_events))
             except queue.Full:
                 # Only raised when not blocking, which means that extra events
                 # should be dropped.
                 self.dropcount += 1
-                pass
         except Exception as e:
             if self.raise_exceptions:
                 raise e
